@@ -337,6 +337,7 @@ types: list[str] = [
     "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
+    "AWS::DataZone::FormType",
     "AWS::DataZone::GroupProfile",
     "AWS::DataZone::Owner",
     "AWS::DataZone::PolicyGrant",
@@ -848,6 +849,8 @@ types: list[str] = [
     "AWS::Neptune::DBParameterGroup",
     "AWS::Neptune::DBSubnetGroup",
     "AWS::Neptune::EventSubscription",
+    "AWS::NeptuneGraph::Graph",
+    "AWS::NeptuneGraph::PrivateGraphEndpoint",
     "AWS::NetworkFirewall::Firewall",
     "AWS::NetworkFirewall::FirewallPolicy",
     "AWS::NetworkFirewall::LoggingConfiguration",
@@ -872,6 +875,8 @@ types: list[str] = [
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
+    "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
     "AWS::OpenSearchServerless::Index",
@@ -1061,6 +1066,13 @@ types: list[str] = [
     "AWS::SES::ReceiptRuleSet",
     "AWS::SES::Template",
     "AWS::SES::VdmAttributes",
+    "AWS::SMSVOICE::ConfigurationSet",
+    "AWS::SMSVOICE::OptOutList",
+    "AWS::SMSVOICE::PhoneNumber",
+    "AWS::SMSVOICE::Pool",
+    "AWS::SMSVOICE::ProtectConfiguration",
+    "AWS::SMSVOICE::ResourcePolicy",
+    "AWS::SMSVOICE::SenderId",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
     "AWS::SNS::TopicInlinePolicy",
@@ -1291,7 +1303,6 @@ cached: list[str] = [
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -1405,7 +1416,6 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
-    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-blueprint.json",
@@ -1535,6 +1545,7 @@ cached: list[str] = [
     "aws-connect-emailaddress.json",
     "aws-connect-evaluationform.json",
     "aws-connect-hoursofoperation.json",
+    "aws-connect-instance.json",
     "aws-connect-instancestorageconfig.json",
     "aws-connect-integrationassociation.json",
     "aws-connect-phonenumber.json",
@@ -1581,6 +1592,7 @@ cached: list[str] = [
     "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
+    "aws-datazone-formtype.json",
     "aws-datazone-groupprofile.json",
     "aws-datazone-owner.json",
     "aws-datazone-policygrant.json",
@@ -1987,7 +1999,6 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -2047,6 +2058,7 @@ cached: list[str] = [
     "aws-mediaconvert-jobtemplate.json",
     "aws-mediaconvert-preset.json",
     "aws-mediaconvert-queue.json",
+    "aws-medialive-channel.json",
     "aws-medialive-channelplacementgroup.json",
     "aws-medialive-cloudwatchalarmtemplate.json",
     "aws-medialive-cloudwatchalarmtemplategroup.json",
@@ -2096,29 +2108,27 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
+    "aws-neptunegraph-graph.json",
+    "aws-neptunegraph-privategraphendpoint.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
-    "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
-    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
-    "aws-networkmanager-sitetositevpnattachment.json",
-    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
-    "aws-networkmanager-transitgatewayroutetableattachment.json",
-    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-observabilityadmin-organizationtelemetryrule.json",
+    "aws-observabilityadmin-telemetryrule.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
     "aws-opensearchserverless-index.json",
@@ -2344,7 +2354,6 @@ cached: list[str] = [
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
     "aws-servicecatalog-portfolio.json",
-    "aws-servicecatalog-portfolioprincipalassociation.json",
     "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
     "aws-servicecatalog-resourceupdateconstraint.json",
@@ -2386,6 +2395,13 @@ cached: list[str] = [
     "aws-shield-protectiongroup.json",
     "aws-signer-profilepermission.json",
     "aws-signer-signingprofile.json",
+    "aws-smsvoice-configurationset.json",
+    "aws-smsvoice-optoutlist.json",
+    "aws-smsvoice-phonenumber.json",
+    "aws-smsvoice-pool.json",
+    "aws-smsvoice-protectconfiguration.json",
+    "aws-smsvoice-resourcepolicy.json",
+    "aws-smsvoice-senderid.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
@@ -2438,12 +2454,9 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
-    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourceconfiguration.json",
-    "aws-vpclattice-resourcegateway.json",
-    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
