@@ -184,6 +184,7 @@ types: list[str] = [
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
     "AWS::EC2::CapacityReservation",
+    "AWS::EC2::CapacityReservationFleet",
     "AWS::EC2::ClientVpnAuthorizationRule",
     "AWS::EC2::ClientVpnEndpoint",
     "AWS::EC2::ClientVpnRoute",
@@ -320,6 +321,8 @@ types: list[str] = [
     "AWS::ElasticLoadBalancingV2::TrustStore",
     "AWS::ElasticLoadBalancingV2::TrustStoreRevocation",
     "AWS::Elasticsearch::Domain",
+    "AWS::Events::ApiDestination",
+    "AWS::Events::Connection",
     "AWS::Events::EventBus",
     "AWS::Events::Rule",
     "AWS::FMS::NotificationChannel",
@@ -383,6 +386,8 @@ types: list[str] = [
     "AWS::ImageBuilder::ImageRecipe",
     "AWS::ImageBuilder::InfrastructureConfiguration",
     "AWS::ImageBuilder::Workflow",
+    "AWS::InspectorV2::CisScanConfiguration",
+    "AWS::InspectorV2::Filter",
     "AWS::IoT::Certificate",
     "AWS::IoT::Policy",
     "AWS::IoT::PolicyPrincipalAttachment",
@@ -392,6 +397,9 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::KafkaConnect::Connector",
+    "AWS::KafkaConnect::CustomPlugin",
+    "AWS::KafkaConnect::WorkerConfiguration",
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
@@ -454,6 +462,8 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
@@ -503,6 +513,7 @@ types: list[str] = [
     "AWS::Route53Resolver::FirewallRuleGroup",
     "AWS::Route53Resolver::FirewallRuleGroupAssociation",
     "AWS::Route53Resolver::ResolverConfig",
+    "AWS::Route53Resolver::ResolverDNSSECConfig",
     "AWS::Route53Resolver::ResolverEndpoint",
     "AWS::Route53Resolver::ResolverQueryLoggingConfig",
     "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation",
@@ -620,7 +631,8 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -676,6 +688,7 @@ cached: list[str] = [
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
+    "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
     "aws-certificatemanager-certificate.json",
@@ -753,7 +766,10 @@ cached: list[str] = [
     "aws-dms-dataprovider.json",
     "aws-dms-instanceprofile.json",
     "aws-dms-migrationproject.json",
+    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
+    "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnendpoint.json",
     "aws-ec2-clientvpnroute.json",
     "aws-ec2-clientvpntargetnetworkassociation.json",
@@ -832,6 +848,7 @@ cached: list[str] = [
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
@@ -882,6 +899,8 @@ cached: list[str] = [
     "aws-emr-instancegroupconfig.json",
     "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
+    "aws-events-apidestination.json",
+    "aws-events-connection.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
     "aws-fms-notificationchannel.json",
@@ -939,7 +958,12 @@ cached: list[str] = [
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-workflow.json",
+    "aws-inspectorv2-cisscanconfiguration.json",
+    "aws-inspectorv2-filter.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-kafkaconnect-connector.json",
+    "aws-kafkaconnect-customplugin.json",
+    "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
@@ -958,7 +982,6 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1002,6 +1025,8 @@ cached: list[str] = [
     "aws-pcaconnectorad-serviceprincipalname.json",
     "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rds-dbcluster.json",
@@ -1048,6 +1073,7 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
