@@ -7,6 +7,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Workspace",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
@@ -306,6 +307,7 @@ types: list[str] = [
     "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
+    "AWS::ECR::RepositoryCreationTemplate",
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
     "AWS::ECS::ClusterCapacityProviderAssociations",
@@ -364,6 +366,9 @@ types: list[str] = [
     "AWS::Events::Rule",
     "AWS::FIS::ExperimentTemplate",
     "AWS::FIS::TargetAccountConfiguration",
+    "AWS::FMS::NotificationChannel",
+    "AWS::FMS::Policy",
+    "AWS::FMS::ResourceSet",
     "AWS::FSx::DataRepositoryAssociation",
     "AWS::FSx::FileSystem",
     "AWS::FSx::Snapshot",
@@ -458,6 +463,7 @@ types: list[str] = [
     "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
+    "AWS::IoT::EncryptionConfiguration",
     "AWS::IoT::FleetMetric",
     "AWS::IoT::JobTemplate",
     "AWS::IoT::Logging",
@@ -583,6 +589,7 @@ types: list[str] = [
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
+    "AWS::QuickSight::Folder",
     "AWS::QuickSight::RefreshSchedule",
     "AWS::QuickSight::Template",
     "AWS::QuickSight::Theme",
@@ -601,6 +608,7 @@ types: list[str] = [
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::OptionGroup",
+    "AWS::RUM::AppMonitor",
     "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
@@ -661,6 +669,13 @@ types: list[str] = [
     "AWS::SES::EmailIdentity",
     "AWS::SES::Template",
     "AWS::SES::VdmAttributes",
+    "AWS::SMSVOICE::ConfigurationSet",
+    "AWS::SMSVOICE::OptOutList",
+    "AWS::SMSVOICE::PhoneNumber",
+    "AWS::SMSVOICE::Pool",
+    "AWS::SMSVOICE::ProtectConfiguration",
+    "AWS::SMSVOICE::ResourcePolicy",
+    "AWS::SMSVOICE::SenderId",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
     "AWS::SNS::TopicPolicy",
@@ -806,6 +821,7 @@ cached: list[str] = [
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -816,6 +832,7 @@ cached: list[str] = [
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
     "aws-apigatewayv2-domainname.json",
+    "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
@@ -827,6 +844,7 @@ cached: list[str] = [
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
+    "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
@@ -846,6 +864,7 @@ cached: list[str] = [
     "aws-appstream-applicationfleetassociation.json",
     "aws-appstream-directoryconfig.json",
     "aws-appstream-entitlement.json",
+    "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-workspace.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
@@ -872,13 +891,11 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
-    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
@@ -919,7 +936,6 @@ cached: list[str] = [
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
     "aws-codepipeline-customactiontype.json",
-    "aws-codepipeline-webhook.json",
     "aws-codestarconnections-connection.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
@@ -974,6 +990,8 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
+    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnendpoint.json",
@@ -1065,9 +1083,12 @@ cached: list[str] = [
     "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
+    "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
+    "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1080,13 +1101,17 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
+    "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
+    "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
+    "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
@@ -1109,6 +1134,9 @@ cached: list[str] = [
     "aws-eventschemas-schema.json",
     "aws-fis-experimenttemplate.json",
     "aws-fis-targetaccountconfiguration.json",
+    "aws-fms-notificationchannel.json",
+    "aws-fms-policy.json",
+    "aws-fms-resourceset.json",
     "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
@@ -1146,6 +1174,7 @@ cached: list[str] = [
     "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-iam-accesskey.json",
+    "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
     "aws-iam-managedpolicy.json",
@@ -1181,6 +1210,7 @@ cached: list[str] = [
     "aws-iot-command.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
+    "aws-iot-encryptionconfiguration.json",
     "aws-iot-fleetmetric.json",
     "aws-iot-jobtemplate.json",
     "aws-iot-logging.json",
@@ -1206,6 +1236,7 @@ cached: list[str] = [
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisanalyticsv2-applicationoutput.json",
+    "aws-kinesisfirehose-deliverystream.json",
     "aws-kinesisvideo-signalingchannel.json",
     "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
@@ -1221,8 +1252,8 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
+    "aws-lambda-layerversion.json",
+    "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
@@ -1231,6 +1262,8 @@ cached: list[str] = [
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
+    "aws-logs-destination.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1273,9 +1306,9 @@ cached: list[str] = [
     "aws-opensearchserverless-collection.json",
     "aws-opensearchserverless-index.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
-    "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-instance.json",
@@ -1288,13 +1321,12 @@ cached: list[str] = [
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pcs-cluster.json",
-    "aws-pcs-computenodegroup.json",
     "aws-pcs-queue.json",
     "aws-quicksight-analysis.json",
-    "aws-quicksight-custompermissions.json",
     "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
+    "aws-quicksight-folder.json",
     "aws-quicksight-refreshschedule.json",
     "aws-quicksight-template.json",
     "aws-quicksight-theme.json",
@@ -1302,6 +1334,7 @@ cached: list[str] = [
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
+    "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
@@ -1313,13 +1346,16 @@ cached: list[str] = [
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-optiongroup.json",
+    "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
     "aws-redshift-clustersubnetgroup.json",
+    "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
+    "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1330,6 +1366,8 @@ cached: list[str] = [
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-dnssec.json",
+    "aws-route53-healthcheck.json",
+    "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
@@ -1342,6 +1380,7 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
@@ -1362,6 +1401,7 @@ cached: list[str] = [
     "aws-sagemaker-imageversion.json",
     "aws-sagemaker-modelcard.json",
     "aws-sagemaker-pipeline.json",
+    "aws-sagemaker-processingjob.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-scheduler-schedule.json",
@@ -1390,13 +1430,11 @@ cached: list[str] = [
     "aws-servicecatalog-cloudformationprovisionedproduct.json",
     "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
-    "aws-servicecatalog-launchtemplateconstraint.json",
     "aws-servicecatalog-portfolioshare.json",
     "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
-    "aws-servicecatalog-tagoption.json",
     "aws-servicecatalogappregistry-application.json",
     "aws-servicecatalogappregistry-attributegroup.json",
     "aws-servicecatalogappregistry-attributegroupassociation.json",
@@ -1416,6 +1454,13 @@ cached: list[str] = [
     "aws-signer-profilepermission.json",
     "aws-signer-signingprofile.json",
     "aws-simspaceweaver-simulation.json",
+    "aws-smsvoice-configurationset.json",
+    "aws-smsvoice-optoutlist.json",
+    "aws-smsvoice-phonenumber.json",
+    "aws-smsvoice-pool.json",
+    "aws-smsvoice-protectconfiguration.json",
+    "aws-smsvoice-resourcepolicy.json",
+    "aws-smsvoice-senderid.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicpolicy.json",
@@ -1440,6 +1485,7 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
+    "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
